@@ -31,7 +31,7 @@
 
 #include "config.h"
 
-static Lum::AppInfo info;
+static Lum::Def::AppInfo info;
 
 class MainWindow : public Lum::Dialog
 {
